#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME=$(uci get owncast.@owncast[0].image_name 2>/dev/null)
}

do_install_detail() {
  local config=`uci get owncast.@owncast[0].config_path 2>/dev/null`
  local port=`uci get owncast.@owncast[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get owncast.@owncast[0].image_name 2>/dev/null`
  
  # Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
  
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8387
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=owncast/owncast:latest
  
  # Create Docker Compose file with custom variables
  rm -R /opt/docker2/compose/owncast-app
  mkdir /opt/docker2/compose/owncast-app
  touch /opt/docker2/compose/owncast-app/docker-compose.yml
  cat > /opt/docker2/compose/owncast-app/docker-compose.yml <<EOF
version: '3.8'
services:
  owncast:
    image: $IMAGE_NAME
    restart: unless-stopped
    ports:
      - ${LAN_IP}:$port:8080
    environment:
      - OWNCAST_ADMIN_USERNAME=admin
      - OWNCAST_ADMIN_PASSWORD=password
      - OWNCAST_TITLE=My Owncast Stream
      - OWNCAST_STREAM_KEY=${GEN_PASS}
      - OWNCAST_HTTP_ROOT=/stream
    volumes:
      - $config:/app/data
    labels:
      plugsy.name: "Owncast"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/simple-icons/Owncast"
      plugsy.link: "http://${LAN_IP}:$port"
EOF
  
  docker-compose -f /opt/docker2/compose/owncast-app/docker-compose.yml up -d
  
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu
}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install owncast"
  echo "      upgrade                Upgrade owncast"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart owncast"
  echo "      status                 owncast status"
  echo "      port                   owncast port"
}

case ${ACTION} in
  "install"|"upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    get_image
    docker-compose -f /opt/docker2/compose/owncast-app/docker-compose.yml down
  ;;
  "start"|"stop"|"restart")
    get_image
    docker-compose -f /opt/docker2/compose/owncast-app/docker-compose.yml ${ACTION}
  ;;
  "status")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Status}}'
  ;;
  "port")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
